@@ -51,7 +51,11 @@ class Registro(RegistroBase):
 
     @property
     def pedido_numero(self):
-        return self.dados["referencia"]
+        if "referencia" in self.dados:
+            return self.dados["referencia"]
+        if "paymentrequest_0_invnum" in self.dados:
+            return self.dados["paymentrequest_0_invnum"]
+        return None
 
     @property
     def identificador_id(self):
@@ -134,7 +138,8 @@ class Registro(RegistroBase):
             self._valores_de_pagamento["identificador_id"] = retorno["token"].upper()
         if "paymentinfo_0_amt" in retorno:
             self._valores_de_pagamento["valor_pago"] = self.formatador.string_para_decimal(retorno["paymentinfo_0_amt"])
-
+        if self.retorno_de_notificacao:
+            self.dados.update(retorno)
         return {"content": retorno, "status": 200 if self.sucesso else 500, "reenviar": False}
 
     @property
